#-*- coding: utf-8 -*-
#############################################################################
#                                                                           #
#   Copyright (c) 2008 Gregor Giesen <giesen@zaehlwerk.net>                 #
#                                                                           #
# This program is free software; you can redistribute it and/or modify      #
# it under the terms of the GNU General Public License as published by      #
# the Free Software Foundation; either version 3 of the License, or         #
# (at your option) any later version.                                       #
#                                                                           #
# This program is distributed in the hope that it will be useful,           #
# but WITHOUT ANY WARRANTY; without even the implied warranty of            #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             #
# GNU General Public License for more details.                              #
#                                                                           #
# You should have received a copy of the GNU General Public License         #
# along with this program.  If not, see <http://www.gnu.org/licenses/>.     #
#                                                                           #
#############################################################################
"""
$Id$
"""
__docformat__ = 'reStructuredText'

from zw.widget.i18n import MessageFactory as _
from zope import schema
from z3c.form.interfaces import IWidget

class IEmailWidget(IWidget):
    """An email widget.
    """

    obscured = schema.Bool(
        title = _( u'label-zw.widget.email.obscured',
                   u"Obscured" ),
        description = _( u'help-zw.widget.email.obscured',
                         u"If true the address will be obscured "
                         u"to protect from spam bots." ),
        default = True )
